      SUBROUTINE VDIVK(VECR, NVEC, CONST)
C
C***********************************************************************
C
C   NAME- VDIVK
C
C   LANGUAGE- FORTRAN 77       TYPE- SUBROUTINE       COMPUTER- CRAY   
C
C   VERSION- 1.0  DATE- 07/13/89  PROGRAMMER- S.SWEETLAND (SMSRC)
C   VERSION- 3.0  DATE- 05/10/96  PROGRAMMER- A.POZDNYAK (FDC)    
C     FOR REHOSTING TO THE CRAY, CHANGED ALL I*4 DECLARATIONS TO
C      INTEGER AND ALL R*4 DECLARATIONS TO REAL.
C   VERSION- 4.0    DATE- 02/27/03   PROGRAMMER- Rickey Rollins (CSC)
C        Replace R4SPV equivalence test with ISR4SPV function 
C
C   FUNCTION- DIVIDES EACH ELEMENT OF A VECTOR BY THE VALUE OF CONSTANT
C
C   CALLING SEQUENCE PARAMETERS-
C
C   NAME   TYPE  I/O    DESCRIPTION
C
C   VECR   REAL  I/O    REAL VECTOR OF DIMENSION NVEC
C   NVEC   INT   I      NUMBER OF ELEMENTS IN VECR
C   CONST  REAL  I      REAL CONSTANT
C
C***********************************************************************
C
      INTEGER NVEC
      REAL    CONST, VECR(NVEC)
      LOGICAL   ISR4SPV
C
      INCLUDE 'SPVAL'
C
      IF(CONST .NE. 0.)THEN
         DO 10 J = 1,NVEC
           IF (.NOT. ISR4SPV(VECR(J)))  VECR(J) = VECR(J)/CONST
   10    CONTINUE
      ENDIF
C
      RETURN
      END
